# Clean ENOA

[![codecov](https://codecov.io/gh/nepito/clean-enoa/branch/main/graph/badge.svg?token=DIoEtHqRMU)](https://codecov.io/gh/nepito/clean-enoa)
![example branch parameter](https://github.com/nepito/clean-enoa/actions/workflows/actions.yml/badge.svg)

Get a token [here](http://www3.inegi.org.mx//sistemas/api/indicadores/v1/tokenVerify.aspx).
